% Autokorrelationsfunktion und Autoleistungsspektrum fuer ungleichmaessig abgetastete Signale mit wirklich streng periodischen Anteilen
% mit Slotkorrelation (als Referenz - langsam), hier ohne Gewichtung, Gewichtung in sperslotw.m
% Slotkorrelation, direkte Spektralschaetzung und Zeitquantisierung ergeben leicht unterschiedliche Ergebnisse
function [tau,R,f,P]=sperslot(x,t,dt,NT)
  % x - Datensatz
  % t - Messzeitpunkte (gleiche Laenge wie x)
  % dt - Zeitschritt (fuer Korrelationsfunktion und Spektrum)
  % NT - angenommene Periodenlaenge (Vielfache des Zeitschritts)
  N=length(x);
  tau=(0:NT-1)*dt;
  R1=zeros(1,NT);
  R0=zeros(1,NT);
  for i=1:N
    for j=1:N
      k=mod(round((t(j)-t(i))/dt),NT)+1;
      R1(k)=R1(k)+x(i)*x(j);
      R0(k)=R0(k)+1;
    end
  end
  R=R1./R0;
  df=1/(NT*dt);
  f=(mod((0:NT-1)+fix(NT/2),NT)-fix(NT/2))*df;
  P=real(fft(R))/NT;
end

